
API_URL = "http://apiadvisor.climatempo.com.br"
TOKEN_PARAMETER_STR = "token"
LATITUDE_PARAMETER_STR = "latitude"
LONGITUDE_PARAMETER_STR = "longitude"
CURRENT_WEATHER_URL="/api/v1/weather/locale/{}/current"
FORECAST_72_HOURS_URL = "/api/v1/forecast/locale/{}/hours/72"
FORECAST_15_DAYS_URL = "/api/v1/forecast/locale/{}/days/15"
SEARCH_LOCALE_URL = "/api/v1/locale/city"
